@@ -31,7 +31,7 @@ from ..event_util import forward_event_with_results, forward_event
 from ..pubsub import PubSubClient
 
 if TYPE_CHECKING:
-    from ..pubsub import PubSubData
+    from ..pubsub import PubSubData, PubSubPointRedemption
 
 
 # noinspection PyMethodMayBeStatic
@@ -180,6 +180,13 @@ class BaseBot:
         triggered when data is received from the pubsub client
         """
 
+    async def on_pubsub_custom_channel_point_reward(self, raw: 'PubSubData', data: 'PubSubPointRedemption'):
+        """
+        triggered when a user redeems a channel's custom channel point reward
+        :param raw: the raw pubsub message
+        :param data: data specific to the custom channel point reward redeemed
+        """
+
     # endregion
 
     def _create_channels(self):
