@@ -1,11 +1,14 @@
 from typing import Optional, TYPE_CHECKING
 
 __all__ = [
-    'get_bot', 'set_bot'
+    'get_bot',
+    'set_bot',
+    'get_pubsub',
 ]
 
 if TYPE_CHECKING:
     from .bots import BaseBot
+    from .pubsub import PubSubClient
 
 _bot: Optional['BaseBot'] = None
 
@@ -17,3 +20,7 @@ def get_bot() -> Optional['BaseBot']:
 def set_bot(bot: 'BaseBot'):
     global _bot
     _bot = bot
+
+
+def get_pubsub() -> 'PubSubClient':
+    return get_bot().pubsub
